@@ -5,9 +5,9 @@ use warnings;
 use warnings qw(FATAL utf8); # Fatalize encoding glitches.
 
 our $Debug   = 0;
-our $VERSION = '1.30';
+our $VERSION = '1.33';
 
-use File::Slurp::Tiny 'read_lines';
+use File::Slurper 'read_lines';
 
 # -----------------------------------------------
 
@@ -1113,7 +1113,7 @@ sub read_tree
 	my(@stack);
 	my($tos);
 
-	for my $line (read_lines($file_name, binmode => ':encoding(utf-8)', chomp => 1) )
+	for my $line (read_lines($file_name, 'UTF-8', 0) )
 	{
 		$count++;
 
@@ -3368,7 +3368,7 @@ L<https://github.com/ronsavage/Tree-DAG_Node>
 
 Email the author, or log a bug on RT:
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-DAG_Node>.
+L<https://github.com/ronsavage/Tree-DAG_Node/issues>.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -3391,8 +3391,10 @@ Sean M. Burke, C<< <sburke@cpan.org> >>
 
 Copyright 1998-2001, 2004, 2007 by Sean M. Burke and David Hand.
 
-This program is free software. It is released under the Artistic License 2.0.
-See L<http://opensource.org/licenses/Artistic-2.0>.
+This Program of ours is 'OSI Certified Open Source Software';
+you can redistribute it and/or modify it under the terms of
+The Perl License, a copy of which is available at:
+http://dev.perl.org/licenses/
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
